#
# spec file for package AppStream
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define libappstream_sover 4

Name:           AppStream
Version:        0.10.0
Release:        2.2
Summary:        Utilities to generate, maintain and access the AppStream Xapian database
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            https://www.freedesktop.org/software/appstream/docs/
Source:         http://www.freedesktop.org/software/appstream/releases/%{name}-%{version}.tar.xz
BuildRequires:  cmake >= 3.1.0
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  xmlto
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(packagekit-glib2)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(xapian-core)
BuildRequires:  pkgconfig(yaml-0.1)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
AppStream-Core makes it easy to access application information from the
AppStream database over a nice GObject-based interface.

%package -n libappstream%{libappstream_sover}
Summary:        The main library for AppStream
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Libraries

%description -n libappstream%{libappstream_sover}
The main library for AppStream.

%package -n libAppstreamQt1
Summary:        Qt5 bindings for AppStream
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Libraries

%description -n libAppstreamQt1
The Qt5 bindings for AppStream.

%package -n libAppstreamQt-devel
Summary:        Needed include files and libraries for development
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       libAppstreamQt1 = %{version}
Requires:       libappstream%{libappstream_sover} = %{version}

%description -n libAppstreamQt-devel
This package contains all necessary include files, libraries,
configuration files and development tools (with manual pages) needed to
compile and link applications using the Qt bindings for AppStream.

%package devel
Summary:        Needed include files and libraries for development
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       libappstream%{libappstream_sover} = %{version}

%description devel
This package contains all necessary include files, libraries,
configuration files and development tools (with manual pages) needed to
compile and link applications using AppStream.

%package -n typelib-1_0-AppStream-1.0
Summary:        Simple software installation management software -- Introspection bindings
License:        LGPL-2.1+
Group:          System/Libraries

%description -n typelib-1_0-AppStream-1.0
PackageKit is a system designed to make installing and updating
software on your computer easier.  The primary design goal is to unify
all the software graphical tools used in different distributions, and
use some of the latest technology like PolicyKit to make the process
suck less.

%lang_package

%prep
%setup -q

%build
%if "%{?_lib}" == "lib64"
SUFFIX="64"
%else
SUFFIX=""
%endif

%cmake -DQT=ON \
       -DVAPI=ON \
       -DINSTALL_PREBUILT_DOCS=OFF \
       -DDOCUMENTATION=OFF \
       -DSTEMMING=OFF \
       -DAPPSTREAM_QT_VERSION=5

%make_jobs

%install
%make_install -C build

%find_lang appstream %{name}.lang

%post -n libappstream%{libappstream_sover} -p /sbin/ldconfig

%postun -n libappstream%{libappstream_sover} -p /sbin/ldconfig

%post -n libAppstreamQt1 -p /sbin/ldconfig

%postun -n libAppstreamQt1 -p /sbin/ldconfig

%files lang -f %{name}.lang

%files
%defattr(-,root,root)
%doc LICENSE* NEWS
%{_bindir}/appstreamcli
%config(noreplace) %{_sysconfdir}/appstream.conf
#dir %{_datadir}/app-info
#{_datadir}/app-info/categories.xml
%{_mandir}/man1/appstreamcli.*

%files -n libappstream%{libappstream_sover}
%defattr(-,root,root)
%doc LICENSE* NEWS
%{_libdir}/libappstream.so.*

%files -n libAppstreamQt1
%defattr(-,root,root)
%doc LICENSE*
%{_libdir}/libAppstreamQt.so.*

%files -n libAppstreamQt-devel
%defattr(-,root,root)
%{_includedir}/AppstreamQt/
%{_libdir}/cmake/AppstreamQt/
%{_libdir}/libAppstreamQt.so

%files devel
%defattr(-,root,root)
%{_libdir}/libappstream.so
%{_libdir}/pkgconfig/appstream.pc
%{_includedir}/AppStream/
%{_datadir}/gir-1.0/AppStream-1.0.gir
%{_datadir}/gettext/
%dir %{_datadir}/vala/
%dir %{_datadir}/vala/vapi/
%{_datadir}/vala/vapi/appstream.vapi

%files -n typelib-1_0-AppStream-1.0
%defattr(-,root,root)
%doc LICENSE*
%{_libdir}/girepository-1.0/AppStream-1.0.typelib

%changelog
* Fri Sep 16 2016 alarrosa@suse.com
- Update to version 0.10.0
- Disable stemming support until we have libstemmer packaged.
- Generate libappstream4 packages since AppStream changes the ABI in 0.10.0
  Notes:
  * This release breaks API/ABI in order to support multiple metadata sets describing the same
  component (needed for bundling support), moving away from the database as central data store
  and general cleanup.
  * Porting is relatively straightforward, if you were using AsDatabase, you should switch to AsPool
  now (AsDatabase has been a wrapper around AsPool for a while anyway).
  * Many methods became private API with this release, file a bug if you miss anything.
  * The 'categories.xml' file is gone - please account for that if you were reading it directly,
  and consider using AsCategory instead, which offers the same functionality.
  Features:
  * Remove the AsDatabase class (Matthias Klumpp)
  * Use cmakedefine for compile-time features (Matthias Klumpp)
  * Rename AsDataPool -> AsPool (Matthias Klumpp)
  * Add placeholder enum for web applications (Matthias Klumpp)
  * qt: Implement Appstream::Release for the Qt interface (Aleix Pol)
  * Recognize the "Pantheon" desktop for Elementary (Matthias Klumpp)
  * Get rid of the menu parser and make AsCategory more useful instead (Matthias Klumpp)
  * Allow AsComponent to automatically check for list-value duplicates (Matthias Klumpp)
  * Give bundles their own class (Matthias Klumpp)
  * Stop shipping the categories.xml file (Matthias Klumpp)
  * Allow multiple metadata sets in the pool to describe a component (Matthias Klumpp)
  * Name AppStream metadata styles consistently (Matthias Klumpp)
  * Allow the 'C' description fallback to be turned off (Iain Lane)
  * Make AsScreenshot return localized images by default (Matthias Klumpp)
  * Allow to compare AsRelease versions easily (Matthias Klumpp)
  * Make get_icon_repository_paths private API (Matthias Klumpp)
  * ascli: Allow dumping metadata as YAML (Matthias Klumpp)
  * Use GVariant instead of ProtoBuf based cache (Matthias Klumpp)
  * Enable stemming by default (Matthias Klumpp)
  * Make components directly reference their addons, avoiding to query twice (Matthias Klumpp)
  * Refactor data pool metadata loading (Matthias Klumpp)
  * Allow setting the AppStream format version when (de)serializing data (Matthias Klumpp)
  * Always write modern metadata, unless a lower format version is requested explicitly (Matthias Klumpp)
  * Also find components in searches which have the search keyword in an addon (Matthias Klumpp)
  * ascli: Add function to convert XML to YAML and vice versa (Matthias Klumpp)
  * Consistent naming for metadata format and style (Matthias Klumpp)
  Specification:
  * spec: Add hint on how the keywords tag should be localized (Matthias Klumpp)
  Bugfixes:
  * Resolve unit test failures on arm and mips (Matthias Klumpp)
  * gir: Correctly annotate ownership transference of GPtrArrays (Matthias Klumpp)
  * l10n: Drop languages without translations (Matthias Klumpp)
  * Don't hide symbols in public headers (Matthias Klumpp)
  * Properly validate desktop-environment strings (Matthias Klumpp)
  * validator: Fix name/summary check in validate-tree (Matthias Klumpp)
  * xml: Properly write localized keywords (Matthias Klumpp)
  * Avoid watching superfluous directories for metadata (Matthias Klumpp)
  * Update architecture diagrams and optimize PNGs (Matthias Klumpp)
  * Get rid of Xapian-isms (Matthias Klumpp)
* Fri Sep 16 2016 alarrosa@suse.com
- Update to version 0.9.8
  Features:
  * qt: Different approach for storing the icon size and url relation (Aleix Pol)
  * Strictly validate AppStream IDs (Matthias Klumpp)
  * Add AsSuggested class (Lucas Moura)
  * tests: Test merges for suggestions (Lucas Moura)
  * Add functions handling SPDX license ids and expressions (Matthias Klumpp)
  * validator: Include a line-hint in the issue report (Matthias Klumpp)
  * Implement console-application component type (Matthias Klumpp)
  * validator: Validate files following the new cid scheme properly (Matthias Klumpp)
  * validator: Validate metadata_license for permissiveness (Matthias Klumpp)
  * Compress cache data (Matthias Klumpp)
  * Implement "translate" URL type (Matthias Klumpp)
  * xml: Implement the suggests tag (Matthias Klumpp)
  * yaml: Implement reading and writing of Suggests field (Matthias Klumpp)
  * Consider merge components valid if they have at least an ID (Matthias Klumpp)
  * yaml: Read/write merge components (Matthias Klumpp)
  Specification:
  * spec: Add console-application component type (Matthias Klumpp)
  * spec: Streamline the requirements for component-ids (Matthias Klumpp)
  * spec: Define a "translate" URL type (Matthias Klumpp)
  * spec: Specify the suggests tag (Matthias Klumpp)
  * spec: Describe the merge property (Matthias Klumpp)
  * spec: Proofreading fixes (Philip Withnall)
  Bugfixes:
  * Make searching for multiple terms work properly again (Matthias Klumpp)
  * Don't fail on invalid search terms (Matthias Klumpp)
  * Don't re-instantiate stemmer on each use (Matthias Klumpp)
  * ascli: Line-wrap unicode texts properly on the console (Matthias Klumpp)
  * Add missing docs to the API reference (Matthias Klumpp)
  * tests: Add test description to each test (Matthias Klumpp)
  * Sort search results by default (Matthias Klumpp)
  * Fix a few issues with merging (Matthias Klumpp)
- From version 0.9.7
  Features:
  * Don't fall back to Debian screenshots server if none is specified for the distro (Matthias Klumpp)
  * Split out distro-specific helpers (Matthias Klumpp)
  * Implement Xapian-less search (Matthias Klumpp)
  * Use a pure PB cache instead of Xapian (Matthias Klumpp)
  * qt: Don't rely on Xapian for searches (Matthias Klumpp)
  * Deprecate AsDatabase (Matthias Klumpp)
  * Hide internal symbols from the symbols table (Matthias Klumpp)
  * Allow injecting components into the pool and unittest the cache (Matthias Klumpp)
  * Add by-category filter to AsDataPool (Matthias Klumpp)
  * Validate Freedesktop category names (Matthias Klumpp)
  * Allow building AppStream with stemming support (Matthias Klumpp)
  * Cache search tokens (Matthias Klumpp)
  Specification:
  * docs/quickstart: Clarify the role of releases/provides (Matthias Klumpp)
  * docs/quickstart: Screenshot images don't need to define width/height (Matthias Klumpp)
  Bugfixes:
  * qt: Properly expose enums for introspection (Aleix Pol)
  * qt: Make it possible to easily output data types using QDebug (Aleix Pol)
  * xml: Fix formatting of <screenshot/> tag (Matthias Klumpp)
  * xml: Work around non-threadsafe behavior of libxml2 (Matthias Klumpp)
  * xml: Properly write provides tag (Matthias Klumpp)
  * Fix code documentation for as_component_get_id (Lucas Moura)
  * Fix some xmldata methods documentation (Lucas Moura)
  * cli: Create metainfo directory if it is missing and respect DESTDIR (Matthias Klumpp)
* Thu Jun  9 2016 mailaender@opensuse.org
- Update to version 0.9.6
  Features:
  * Improve metadata file decompression code (Matthias Klumpp)
  * validator: Simplify loading of data too (Matthias Klumpp)
  * Make it easy to compile with Address Sanitizer enabled (Matthias Klumpp)
  * Allow compiling with UBSan as well (Matthias Klumpp)
  * Add back support for Travis CI (Matthias Klumpp)
  * yaml: Write Releases field (Matthias Klumpp)
  Bugfixes:
  * qt: Properly check for component validity (Matthias Klumpp)
  * Ensure decompressed metadata is null-terminated (Neil Mayhew)
  * validator: Long descriptions are not needed for generic components
  (Matthias Klumpp)
  * Make VAPI generation depend on GIR typelibs explicitly (Matthias Klumpp)
  * Be more verbose when failing to move the cache directory (Matthias Klumpp)
  * Handle format errors when parsing YAML metadata (Neil Mayhew)
* Wed May 18 2016 tittiatcoke@gmail.com
- Drop the separate Vala package and include the files into the
  devel package
* Sun May  8 2016 jengelh@inai.de
- Drop unnecessary manual library require
- Avoid /bin/sh invocation for simple ldconfig calls
* Fri May  6 2016 mailaender@opensuse.org
- Generate the Vala API
- Update to version 0.9.5
  Features:
  * Update README (Matthias Klumpp)
  * Provide a bit more hints for translators (Matthias Klumpp)
  * Improve error messages when reading broken XML (Matthias Klumpp)
  * Load all XML in AsXMLData (Matthias Klumpp)
  * Implement reading localized images from metadata (Matthias Klumpp)
  * Write localized images in XML/YAML serialize routines (Matthias Klumpp)
  * Unify codepaths for checking compatible locales (Matthias Klumpp)
  * yaml: Implement read/write support for the Languages field (Matthias Klumpp)
  * xml: Serialize and read languages tag properly (Matthias Klumpp)
  * validator: Validate files in legacy paths too (Matthias Klumpp)
  Specification:
  * spec: Allow localized screenshot images (Matthias Klumpp)
  Bugfixes:
  * Refactor icon-finding code and fix rare double-free corruption
  (Matthias Klumpp)
  * Properly validate randomly ordered XML tags for duplicates (Matthias Klumpp)
  * validator: The translation tag is only valid in metainfo files
  (Matthias Klumpp)
  * Be slightly less pedantic about size info when reading screenshot
  images (Matthias Klumpp)
  * xml: Properly write <release/> description tag (Matthias Klumpp)
- From version 0.9.4
  Features:
  * Handle legacy screenshot tags (Matthias Klumpp)
  * Print prettier YAML documents (Matthias Klumpp)
  * yaml: Allow loading of distro metadata slices without header
  (Matthias Klumpp)
  * Do not check for installation candidate on minimal validation
  (Matthias Klumpp)
  * Don't check if component has an installation candidate before
  including it (Matthias Klumpp)
  * Quick-check components only when the pool is fully loaded (Matthias Klumpp)
  * Support the stub data of GNOME Software (Matthias Klumpp)
  * Support reading per-component priorities (Matthias Klumpp)
  * Implement the architecture property (Matthias Klumpp)
  * Use architecture data to resolve conflicting IDs (Matthias Klumpp)
  * Add icon size information to generated XML (Matthias Klumpp)
  * xml: Load size hints for icons (Matthias Klumpp)
  * l10n: Update
  Specification:
  * docs: Explicitly define more minimally required tags per component
  type (Matthias Klumpp)
  * Make /usr/share/metainfo the canonical path for upstream metadata
  (Matthias Klumpp)
  * spec: Make architecture a property of <components/>, and no tag
  (Matthias Klumpp)
  * spec: Update the cached icon DEP-11 specification to allow size
  information (Matthias Klumpp)
  Bugfixes:
  * Fix a few minor issues spotted by the YAML validator (Matthias Klumpp)
  * Correctly build distro XML descriptions from upstream XML (Matthias Klumpp)
  * Be very strict about which elements are allowed in a description
  tag (Matthias Klumpp)
  * yaml: Prevent bool keys (Matthias Klumpp)
  * ascli: Properly print long descriptions and wrap lines (Matthias Klumpp)
  * Export less C++ symbols (Matthias Klumpp)
  * Show a better error message when failing to parse XML (Matthias Klumpp)
  * Allow adding 0x0 icons (Matthias Klumpp)
  * yaml: Implement the updated "cached" icon format in a
  backwards-compatible way (Matthias Klumpp)
  * apt: Drop flat repository entries (Matthias Klumpp)
  * Probe less sizes if we already have size information (Matthias Klumpp)
  * Don't make stubs delete package information from valid components
  (Matthias Klumpp)
  * apt: Handle quoted origin entries properly (Matthias Klumpp)
- From version 0.9.3
  Features:
  * Allow to update an existing component with fresh metadata
  * Implement YAML serialization
  * writer: Allow to omit writing a header/root node
  * cli: Add convenience method to install metainfo files
  * cli: Add a new "status" command for various diagnostic information
  * yaml: Allow unicode
  * Print prettier XML by default
  * l10n: Update
  Bugfixes:
  * Reset umask before building the data cache
  * apt: Work around APT using server mtime for its downloaded files
* Mon Feb 29 2016 tittiatcoke@gmail.com
- Update to version 0.9.2
  Features:
  * qt: Improve usage of Qt containers (Aleix Pol)
  * qt: Implement Component::extends on the Qt front-end (Aleix Pol)
  * qt: Also call reserve for bundles on the Qt frontend (Aleix Pol)
  * validator: strstrip values when reading XML/YAML and validate
    linebreaks in summaries (Matthias Klumpp)
  * validator: Check if a description is present (Matthias Klumpp)
  * Always build with YAML support (Matthias Klumpp)
  * Move XML parser into its own class (Matthias Klumpp)
  * Make data-pool use the new YAML-aware metadata parser (Matthias Klumpp)
  * Simplify data-pool building routine (Matthias Klumpp)
  * Preprocess extension information for frontends (Matthias Klumpp)
  * qt: Use the new extensions property (Matthias Klumpp)
  * Implement translations tag (Matthias Klumpp)
  * cli: Document the "install" command (Matthias Klumpp)
  * l10n: Update
  Specification:
  * spec: Document the translation tag (Matthias Klumpp)
  * doc: Don't use <tip/> tags in documentation (Matthias Klumpp)
  * spec: Mention the essential tags for a type:desktop component (Matthias Klumpp)
  Bugfixes:
  * as-cache-builder: Cope with no YAML documents (Iain Lane)
  * 50appstream: Don't run if we can't write to the system paths (Iain Lane)
  * Check for writability instead of root permissions when updating the cache (Matthias Klumpp)
  * qt: Don't compute screenshot images and then forget about them (Aleix Pol)
  * Add the missing extends property to the Xapian cache (Matthias Klumpp)
  * validator: Don't fail validation for description-less addons. (Matthias Klumpp)
  * Make reading empty cache values more robust (Matthias Klumpp)
  * Check if GIR scanner & compiler are really installed (Matthias Klumpp)
* Fri Feb  5 2016 tittiatcoke@gmail.com
- Update to version 0.9.1
  * Improved Qt5 usage
  * Implement date property on release tags
  * Ship ITS files from KDE upstream
- From version 0.9.0
  * Refactor icon handling
  * Modernize AppStream classes
  * Update translations
  * Drop AsSearchQuery
  * Improve error handling for database queries
* Tue Mar 31 2015 hrvoje.senjan@gmail.com
- Activate appstream-qt5 package
